]> git.sesse.net Git - stockfish/blobdiff - src/tt.h
Rename TranspositionTable 'writes' in 'overwrites'
[stockfish] / src / tt.h
index b43489dd796ebc8aff60902f12766b5ed5bedc7f..46f5b11dd3940864ace0da1c377f95aa8411735d 100644 (file)
--- a/src/tt.h
+++ b/src/tt.h
@@ -115,10 +115,10 @@ public:
   TTEntry* first_entry(const Key posKey) const;
 
 private:
// Be sure 'writes' is at least one cache line away
   // from read only variables.
   unsigned char pad_before[64 - sizeof(unsigned)];
-  unsigned writes; // heavy SMP read/write access here
+  unsigned overwrites; // heavy SMP read/write access here
   unsigned char pad_after[64];
 
   size_t size;
@@ -115,10 +115,10 @@ public:
 
 private:
-  // Be sure 'writes' is at least one cache line away
+  // Be sure 'overwrites' is at least one cache line away
   // from read only variables.
   unsigned char pad_before[64 - sizeof(unsigned)];